package de.duehl.vocabulary.japanese.ui.creation.menu;

import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;

import javax.swing.JMenu;
import javax.swing.JMenuItem;

import de.duehl.swing.ui.menu.MyMenuItem;
import de.duehl.swing.ui.menu.SingleMenuCreation;
import de.duehl.vocabulary.japanese.ui.VocabularyTrainerGui;

/**
 * Diese Klasse erzeugt das Kanji-Menü der graphischen Oberfläche des Vokabel-Trainers.
 *
 * @version 1.01     2024-10-02
 * @author Christian Dühl
 */

public class KanaAndKanjiMenuCreation implements SingleMenuCreation {

    /** Verbindung zur grafischen Oberfläche. */
    private final VocabularyTrainerGui gui;

    /**
     * Konstruktor.
     *
     * @param gui
     *            Verbindung zur grafischen Oberfläche.
     */
    public KanaAndKanjiMenuCreation(VocabularyTrainerGui gui) {
        this.gui = gui;
    }

    /** Erzeugt das Kanji-Menü. */
    @Override
    public JMenu createTheMenu() {
        JMenu menu = new JMenu("Kana und Kanji");
        menu.setMnemonic('k');

        menu.add(createShowHiraganaMenuItem());
        menu.add(createShowKatakanaMenuItem());
        menu.addSeparator();

        menu.add(createShowHiraganaInBrowserMenuItem());
        menu.add(createShowKatakanaInBrowserMenuItem());

        menu.addSeparator();

        menu.add(createShowKanjiTableMenuItem());
        menu.add(createCreateKanjiTestMenuItem());

        return menu;
    }

    private JMenuItem createShowHiraganaMenuItem() {
        return new MyMenuItem("Hiragana anzeigen ...")
                .mnemonic('h')
                //.accelerator(KeyEvent.VK_K, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.showHiragana());
    }

    private JMenuItem createShowKatakanaMenuItem() {
        return new MyMenuItem("Katakana anzeigen ...")
                .mnemonic('n')
                //.accelerator(KeyEvent.VK_K, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.showKatakana());
    }

    private JMenuItem createShowHiraganaInBrowserMenuItem() {
        return new MyMenuItem("Hiragana im Browser anzeigen ...")
                .mnemonic('h')
                //.accelerator(KeyEvent.VK_K, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.showHiraganaInBrowser());
    }

    private JMenuItem createShowKatakanaInBrowserMenuItem() {
        return new MyMenuItem("Katakana im Browser anzeigen ...")
                .mnemonic('n')
                //.accelerator(KeyEvent.VK_K, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.showKatakanaInBrowser());
    }

    private JMenuItem createShowKanjiTableMenuItem() {
        return new MyMenuItem("Kanji-Tabelle anzeigen ...")
                .mnemonic('t')
                .accelerator(KeyEvent.VK_K, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.showKanjiTable());
    }

    private JMenuItem createCreateKanjiTestMenuItem() {
        return new MyMenuItem("Kanji Abfrageliste erstellen ...")
                .mnemonic('a')
                //.accelerator(KeyEvent.VK_F8, InputEvent.CTRL_DOWN_MASK)
                .actionListener(e -> gui.createKanjiTest());
    }

}
