package de.duehl.vocabulary.japanese.website.update;

import de.duehl.vocabulary.japanese.logic.VocabularyTrainerLogic;
import de.duehl.vocabulary.japanese.ui.VocabularyTrainerGui;
import de.duehl.vocabulary.japanese.website.update.ownlists.OwnListGroupsUpdater;
import de.duehl.vocabulary.japanese.website.update.program.ProgramUpdater;
import de.duehl.vocabulary.japanese.website.update.vocables.VocablesUpdater;

/**
 * Diese Klasse kümmert sich um Updates des Programms, der Vokabularien und der bereitgestellten
 * eigenen Listen.
 *
 * @version 1.01     2024-10-05
 * @author Christian Dühl
 */

public class VocabularyTrainerUpdater {


    /** Die Logik des Vokabel-Trainers. */
    private final VocabularyTrainerLogic logic;

    /** Die grafische Oberfläche des Vokabel-Trainers. */
    private final VocabularyTrainerGui gui;

    /**
     * Gibt an, dass die Prüfungen auf neue Versionen beim Start des Programms stattfinden.
     * Anderenfalls hat der Benutzer sie über das Update-Menü angestoßen.
     */
    private boolean checkingNewVersionsOnStartUp;

    /**
     * Konstruktor.
     *
     * @param logic
     *            Die Logik des Vokabel-Trainers.
     * @param gui
     *            Die grafische Oberfläche des Vokabel-Trainers.
     */
    public VocabularyTrainerUpdater(VocabularyTrainerLogic logic, VocabularyTrainerGui gui) {
        this.logic = logic;
        this.gui = gui;

        checkingNewVersionsOnStartUp = false;
    }

    /** Legt fest, dass die Prüfungen auf neue Versionen beim Start des Programms stattfinden. */
    public void checkingNewVersionsOnStartUp() {
        checkingNewVersionsOnStartUp = true;
    }

    /** Auf eine aktuellere Version des Programms prüfen. */
    public void checkNewProgramVersion() {
        ProgramUpdater updater = new ProgramUpdater(logic, gui, checkingNewVersionsOnStartUp);
        updater.update();
    }

    /** Auf eine aktuellere Version der Vokabularien prüfen. */
    public void checkNewVocabulariesVersion() {
        VocablesUpdater updater = new VocablesUpdater(logic, gui, checkingNewVersionsOnStartUp);
        updater.update();
    }

    /** Auf eine aktuellere Version der eigenen Listen prüfen. */
    public void checkNewOwnListsVersion() {
        OwnListGroupsUpdater updater = new OwnListGroupsUpdater(logic, gui,
                checkingNewVersionsOnStartUp);
        updater.update();
    }

}
