package de.duehl.vocabulary.japanese.website.update.ownlists.data;

/**
 * Diese Klasse stellt die Daten einer Zeile aus der Datei Neuste_Version_Listen.txt (ob nun lokal
 * im Falle des Uploads oder von der Webseite heruntergeladen im Falle der Überprüfung auf
 * Neuerungen) dar.
 *
 * @version 1.01     2024-10-06
 * @author Christian Dühl
 */

public class NewestOwnListVersionListEntry {

    /** Der Gruppenname ("FROM_ZERO_1"). */
    private final String groupName;

    /** Die Nummer der Version ("17"). */
    private final int version;

    /**
     * Der Zeitpunkt des letzten Hochladens dieser Gruppe auf den Server als Millisekunden seit
     * Epoch.
     */
    private final long lastUploadTime;

    /**
     * Konstruktor.
     *
     * @param groupName
     *            Der Gruppenname ("FROM_ZERO_1").
     * @param version
     *            Die Nummer der Version ("17").
     * @param lastUploadTime
     *            Der Zeitpunkt des letzten Hochladens dieser Gruppe auf den Server als
     *            Millisekunden seit Epoch.
     */
    public NewestOwnListVersionListEntry(String groupName, int version, long lastUploadTime) {
        this.groupName = groupName;
        this.version = version;
        this.lastUploadTime = lastUploadTime;
    }

    /** Getter für den Gruppennamen ("FROM_ZERO_1"). */
    public String getGroupName() {
        return groupName;
    }

    /** Getter für die Nummer der Version ("17"). */
    public int getVersion() {
        return version;
    }

    /**
     * Getter für den Zeitpunkt des letzten Hochladens dieser Gruppe auf den Server als
     * Millisekunden seit Epoch.
     */
    public long getLastUploadTime() {
        return lastUploadTime;
    }

    @Override
    public String toString() {
        return "NewestOwnListVersionListEntry [groupName=" + groupName + ", version=" + version
                + ", lastUploadTime=" + lastUploadTime + "]";
    }

}
